Master with BDD and AI

# Setup

First make virtual environment

python3 -m venv venv

### After that

source venv/bin/activate

### CONGRATULATIONS! You are in virtual environment

Now create rename .env.example to .env and put there OPEN AI key
